@@ -18,6 +18,9 @@ struct trayclient {
     bool mapped;      /* Whether this window is mapped */
     int xe_version;   /* The XEMBED version supported by the client */
 
+    char *class_class;
+    char *class_instance;
+
     TAILQ_ENTRY(trayclient)
     tailq; /* Pointer for the TAILQ-Macro */
 };
