@@ -19,6 +19,7 @@
 
 #include <X11/Xlib.h>
 
+config_t config;
 static char *cur_key;
 static bool parsing_bindings;
 static bool parsing_tray_outputs;
@@ -345,6 +346,12 @@ static int config_integer_cb(void *params_, long long val) {
         return 1;
     }
 
+    if (!strcmp(cur_key, "workspace_min_width")) {
+        DLOG("workspace_min_width = %lld\n", val);
+        config.ws_min_width = val;
+        return 1;
+    }
+
     return 0;
 }
 
