@@ -41,6 +41,14 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
 #endif
              break;
          case 5:
+             result->next_state = BAR;
+#ifndef TEST_PARSER
+             cfg_bar_workspace_min_width(&current_match, result, get_long("width"));
+#else
+           fprintf(stderr, "cfg_bar_workspace_min_width(%ld)\n", get_long("width"));
+#endif
+             break;
+         case 6:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_focus_on_window_activation(&current_match, result, get_string("mode"));
@@ -48,7 +56,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_focus_on_window_activation(%s)\n", get_string("mode"));
 #endif
              break;
-         case 6:
+         case 7:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_strip_workspace_name(&current_match, result, get_string("value"));
@@ -56,7 +64,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_strip_workspace_name(%s)\n", get_string("value"));
 #endif
              break;
-         case 7:
+         case 8:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_default_border(&current_match, result, get_string("windowtype"), get_string("border"), get_long("width"));
@@ -64,7 +72,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_default_border(%s, %s, %ld)\n", get_string("windowtype"), get_string("border"), get_long("width"));
 #endif
              break;
-         case 8:
+         case 9:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_workspace_back_and_forth(&current_match, result, get_string("value"));
@@ -72,20 +80,12 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_workspace_back_and_forth(%s)\n", get_string("value"));
 #endif
              break;
-         case 9:
+         case 10:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_assign(&current_match, result, get_string("number"), 1);
 #else
            fprintf(stderr, "cfg_assign(%s, %d)\n", get_string("number"), 1);
-#endif
-             break;
-         case 10:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_popup_during_fullscreen(&current_match, result, get_string("value"));
-#else
-           fprintf(stderr, "cfg_popup_during_fullscreen(%s)\n", get_string("value"));
 #endif
              break;
          case 11:
@@ -105,6 +105,14 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
 #endif
              break;
          case 13:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_popup_during_fullscreen(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_popup_during_fullscreen(%s)\n", get_string("value"));
+#endif
+             break;
+         case 14:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_workspace_buttons(&current_match, result, get_string("value"));
@@ -112,7 +120,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_workspace_buttons(%s)\n", get_string("value"));
 #endif
              break;
-         case 14:
+         case 15:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_default_border(&current_match, result, get_string("windowtype"), get_string("border"), 2);
@@ -120,7 +128,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_default_border(%s, %s, %d)\n", get_string("windowtype"), get_string("border"), 2);
 #endif
              break;
-         case 15:
+         case 16:
              result->next_state = WORKSPACE_OUTPUT_WORD;
 #ifndef TEST_PARSER
              cfg_workspace(&current_match, result, get_string("workspace"), get_string("output"));
@@ -128,7 +136,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_workspace(%s, %s)\n", get_string("workspace"), get_string("output"));
 #endif
              break;
-         case 16:
+         case 17:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_separator_symbol(&current_match, result, get_string("separator"));
@@ -136,7 +144,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_separator_symbol(%s)\n", get_string("separator"));
 #endif
              break;
-         case 17:
+         case 18:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_force_focus_wrapping(&current_match, result, get_string("value"));
@@ -144,7 +152,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_force_focus_wrapping(%s)\n", get_string("value"));
 #endif
              break;
-         case 18:
+         case 19:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_bindsym(&current_match, result, get_string("button"), get_string("release"), get_string("command"));
@@ -152,20 +160,12 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_bindsym(%s, %s, %s)\n", get_string("button"), get_string("release"), get_string("command"));
 #endif
              break;
-         case 19:
+         case 20:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_tray_padding(&current_match, result, get_long("padding_px"));
 #else
            fprintf(stderr, "cfg_bar_tray_padding(%ld)\n", get_long("padding_px"));
-#endif
-             break;
-         case 20:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_default_orientation(&current_match, result, get_string("orientation"));
-#else
-           fprintf(stderr, "cfg_default_orientation(%s)\n", get_string("orientation"));
 #endif
              break;
          case 21:
@@ -186,13 +186,21 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
              break;
          case 23:
              result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_default_orientation(&current_match, result, get_string("orientation"));
+#else
+           fprintf(stderr, "cfg_default_orientation(%s)\n", get_string("orientation"));
+#endif
+             break;
+         case 24:
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_focus_follows_mouse(&current_match, result, get_string("value"));
 #else
            fprintf(stderr, "cfg_focus_follows_mouse(%s)\n", get_string("value"));
 #endif
              break;
-         case 24:
+         case 25:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_status_command(&current_match, result, get_string("command"));
@@ -200,7 +208,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_status_command(%s)\n", get_string("command"));
 #endif
              break;
-         case 25:
+         case 26:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_wheel_down_cmd(&current_match, result, get_string("command"));
@@ -208,7 +216,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_wheel_down_cmd(%s)\n", get_string("command"));
 #endif
              break;
-         case 26:
+         case 27:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_color(&current_match, result, get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"), get_string("indicator"), get_string("child_border"));
@@ -216,7 +224,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_color(%s, %s, %s, %s, %s, %s)\n", get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"), get_string("indicator"), get_string("child_border"));
 #endif
              break;
-         case 27:
+         case 28:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_color(&current_match, result, get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"), get_string("indicator"), NULL);
@@ -224,7 +232,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_color(%s, %s, %s, %s, %s, NULL)\n", get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"), get_string("indicator"));
 #endif
              break;
-         case 28:
+         case 29:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_for_window(&current_match, result, get_string("command"));
@@ -232,7 +240,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_for_window(%s)\n", get_string("command"));
 #endif
              break;
-         case 29:
+         case 30:
              result->next_state = BAR_COLORS;
 #ifndef TEST_PARSER
              cfg_bar_color_single(&current_match, result, get_string("colorclass"), get_string("color"));
@@ -240,20 +248,12 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_color_single(%s, %s)\n", get_string("colorclass"), get_string("color"));
 #endif
              break;
-         case 30:
+         case 31:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_floating_modifier(&current_match, result, get_string("modifiers"));
 #else
            fprintf(stderr, "cfg_floating_modifier(%s)\n", get_string("modifiers"));
-#endif
-             break;
-         case 31:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_hide_edge_borders(&current_match, result, get_string("hide_borders"));
-#else
-           fprintf(stderr, "cfg_hide_edge_borders(%s)\n", get_string("hide_borders"));
 #endif
              break;
          case 32:
@@ -339,17 +339,17 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
          case 42:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cfg_assign(&current_match, result, get_string("workspace"), 0);
+             cfg_hide_edge_borders(&current_match, result, get_string("hide_borders"));
 #else
-           fprintf(stderr, "cfg_assign(%s, %d)\n", get_string("workspace"), 0);
+           fprintf(stderr, "cfg_hide_edge_borders(%s)\n", get_string("hide_borders"));
 #endif
              break;
          case 43:
-             result->next_state = BAR;
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cfg_bar_hidden_state(&current_match, result, get_string("hidden_state"));
+             cfg_assign(&current_match, result, get_string("workspace"), 0);
 #else
-           fprintf(stderr, "cfg_bar_hidden_state(%s)\n", get_string("hidden_state"));
+           fprintf(stderr, "cfg_assign(%s, %d)\n", get_string("workspace"), 0);
 #endif
              break;
          case 44:
@@ -362,13 +362,21 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
              break;
          case 45:
              result->next_state = BAR;
+#ifndef TEST_PARSER
+             cfg_bar_hidden_state(&current_match, result, get_string("hidden_state"));
+#else
+           fprintf(stderr, "cfg_bar_hidden_state(%s)\n", get_string("hidden_state"));
+#endif
+             break;
+         case 46:
+             result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_wheel_up_cmd(&current_match, result, get_string("command"));
 #else
            fprintf(stderr, "cfg_bar_wheel_up_cmd(%s)\n", get_string("command"));
 #endif
              break;
-         case 46:
+         case 47:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_ipc_kill_timeout(&current_match, result, get_long("timeout"));
@@ -376,20 +384,12 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_ipc_kill_timeout(%ld)\n", get_long("timeout"));
 #endif
              break;
-         case 47:
+         case 48:
              result->next_state = MODE;
 #ifndef TEST_PARSER
              cfg_mode_binding(&current_match, result, get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("exclude_titlebar"), get_string("command"));
 #else
            fprintf(stderr, "cfg_mode_binding(%s, %s, %s, %s, %s, %s, %s, %s)\n", get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("exclude_titlebar"), get_string("command"));
-#endif
-             break;
-         case 48:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_workspace_layout(&current_match, result, get_string("layout"));
-#else
-           fprintf(stderr, "cfg_workspace_layout(%s)\n", get_string("layout"));
 #endif
              break;
          case 49:
@@ -417,6 +417,14 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
 #endif
              break;
          case 52:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_workspace_layout(&current_match, result, get_string("layout"));
+#else
+           fprintf(stderr, "cfg_workspace_layout(%s)\n", get_string("layout"));
+#endif
+             break;
+         case 53:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_i3bar_command(&current_match, result, get_string("command"));
@@ -424,7 +432,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_i3bar_command(%s)\n", get_string("command"));
 #endif
              break;
-         case 53:
+         case 54:
              result->next_state = BAR_COLORS;
 #ifndef TEST_PARSER
              cfg_bar_color(&current_match, result, get_string("colorclass"), get_string("border"), get_string("background"), NULL);
@@ -432,7 +440,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_color(%s, %s, %s, NULL)\n", get_string("colorclass"), get_string("border"), get_string("background"));
 #endif
              break;
-         case 54:
+         case 55:
              result->next_state = BAR_COLORS;
 #ifndef TEST_PARSER
              cfg_bar_color(&current_match, result, get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"));
@@ -440,7 +448,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_color(%s, %s, %s, %s)\n", get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"));
 #endif
              break;
-         case 55:
+         case 56:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_socket_path(&current_match, result, get_string("path"));
@@ -448,7 +456,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_socket_path(%s)\n", get_string("path"));
 #endif
              break;
-         case 56:
+         case 57:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_tray_output(&current_match, result, get_string("output"));
@@ -456,7 +464,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_tray_output(%s)\n", get_string("output"));
 #endif
              break;
-         case 57:
+         case 58:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_color(&current_match, result, get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"), NULL, NULL);
@@ -464,20 +472,12 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_color(%s, %s, %s, %s, NULL, NULL)\n", get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"));
 #endif
              break;
-         case 58:
+         case 59:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_disable_randr15(&current_match, result, get_string("value"));
 #else
            fprintf(stderr, "cfg_disable_randr15(%s)\n", get_string("value"));
-#endif
-             break;
-         case 59:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_default_border(&current_match, result, get_string("windowtype"), get_string("border"), -1);
-#else
-           fprintf(stderr, "cfg_default_border(%s, %s, %d)\n", get_string("windowtype"), get_string("border"), -1);
 #endif
              break;
          case 60:
@@ -491,9 +491,9 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
          case 61:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cfg_focus_wrapping(&current_match, result, get_string("value"));
+             cfg_default_border(&current_match, result, get_string("windowtype"), get_string("border"), -1);
 #else
-           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+           fprintf(stderr, "cfg_default_border(%s, %s, %d)\n", get_string("windowtype"), get_string("border"), -1);
 #endif
              break;
          case 62:
@@ -594,13 +594,29 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
              break;
          case 74:
              result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 75:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 76:
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_force_xinerama(&current_match, result, get_string("value"));
 #else
            fprintf(stderr, "cfg_force_xinerama(%s)\n", get_string("value"));
 #endif
              break;
-         case 75:
+         case 77:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_assign_output(&current_match, result, get_string("output"));
@@ -608,80 +624,80 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_assign_output(%s)\n", get_string("output"));
 #endif
              break;
-         case 76:
+         case 78:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
              cfg_criteria_add(&current_match, result, get_string("ctype"), get_string("cvalue"));
 #else
            fprintf(stderr, "cfg_criteria_add(%s, %s)\n", get_string("ctype"), get_string("cvalue"));
        cfg_criteria_add(&current_match, result, get_string("ctype"), get_string("cvalue"));
-#endif
-             break;
-         case 77:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_mouse_warping(&current_match, result, get_string("value"));
-#else
-           fprintf(stderr, "cfg_mouse_warping(%s)\n", get_string("value"));
-#endif
-             break;
-         case 78:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_mouse_warping(&current_match, result, get_string("value"));
-#else
-           fprintf(stderr, "cfg_mouse_warping(%s)\n", get_string("value"));
 #endif
              break;
          case 79:
              result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_mouse_warping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_mouse_warping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 80:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_mouse_warping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_mouse_warping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 81:
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_restart_state(&current_match, result, get_string("path"));
 #else
            fprintf(stderr, "cfg_restart_state(%s)\n", get_string("path"));
-#endif
-             break;
-         case 80:
-             result->next_state = BAR;
-#ifndef TEST_PARSER
-             cfg_bar_modifier(&current_match, result, NULL);
-#else
-           fprintf(stderr, "cfg_bar_modifier(NULL)\n");
-#endif
-             break;
-         case 81:
-             result->next_state = BAR;
-#ifndef TEST_PARSER
-             cfg_bar_modifier(&current_match, result, NULL);
-#else
-           fprintf(stderr, "cfg_bar_modifier(NULL)\n");
 #endif
              break;
          case 82:
              result->next_state = BAR;
+#ifndef TEST_PARSER
+             cfg_bar_modifier(&current_match, result, NULL);
+#else
+           fprintf(stderr, "cfg_bar_modifier(NULL)\n");
+#endif
+             break;
+         case 83:
+             result->next_state = BAR;
+#ifndef TEST_PARSER
+             cfg_bar_modifier(&current_match, result, NULL);
+#else
+           fprintf(stderr, "cfg_bar_modifier(NULL)\n");
+#endif
+             break;
+         case 84:
+             result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_modifier(&current_match, result, get_string("modifiers"));
 #else
            fprintf(stderr, "cfg_bar_modifier(%s)\n", get_string("modifiers"));
-#endif
-             break;
-         case 83:
-             result->next_state = BAR;
-#ifndef TEST_PARSER
-             cfg_bar_position(&current_match, result, get_string("position"));
-#else
-           fprintf(stderr, "cfg_bar_position(%s)\n", get_string("position"));
-#endif
-             break;
-         case 84:
-             result->next_state = BAR;
-#ifndef TEST_PARSER
-             cfg_bar_position(&current_match, result, get_string("position"));
-#else
-           fprintf(stderr, "cfg_bar_position(%s)\n", get_string("position"));
 #endif
              break;
          case 85:
+             result->next_state = BAR;
+#ifndef TEST_PARSER
+             cfg_bar_position(&current_match, result, get_string("position"));
+#else
+           fprintf(stderr, "cfg_bar_position(%s)\n", get_string("position"));
+#endif
+             break;
+         case 86:
+             result->next_state = BAR;
+#ifndef TEST_PARSER
+             cfg_bar_position(&current_match, result, get_string("position"));
+#else
+           fprintf(stderr, "cfg_bar_position(%s)\n", get_string("position"));
+#endif
+             break;
+         case 87:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_color_single(&current_match, result, get_string("colorclass"), get_string("color"));
@@ -689,7 +705,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_color_single(%s, %s)\n", get_string("colorclass"), get_string("color"));
 #endif
              break;
-         case 86:
+         case 88:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_fake_outputs(&current_match, result, get_string("outputs"));
@@ -697,7 +713,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_fake_outputs(%s)\n", get_string("outputs"));
 #endif
              break;
-         case 87:
+         case 89:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_no_focus(&current_match, result);
@@ -705,7 +721,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_no_focus()\n");
 #endif
              break;
-         case 88:
+         case 90:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_verbose(&current_match, result, get_string("value"));
@@ -713,28 +729,12 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_verbose(%s)\n", get_string("value"));
 #endif
              break;
-         case 89:
+         case 91:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_binding(&current_match, result, get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("exclude_titlebar"), get_string("command"));
 #else
            fprintf(stderr, "cfg_binding(%s, %s, %s, %s, %s, %s, %s, %s)\n", get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("exclude_titlebar"), get_string("command"));
-#endif
-             break;
-         case 90:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_title_align(&current_match, result, get_string("alignment"));
-#else
-           fprintf(stderr, "cfg_title_align(%s)\n", get_string("alignment"));
-#endif
-             break;
-         case 91:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_title_align(&current_match, result, get_string("alignment"));
-#else
-           fprintf(stderr, "cfg_title_align(%s)\n", get_string("alignment"));
 #endif
              break;
          case 92:
@@ -746,6 +746,22 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
 #endif
              break;
          case 93:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_title_align(&current_match, result, get_string("alignment"));
+#else
+           fprintf(stderr, "cfg_title_align(%s)\n", get_string("alignment"));
+#endif
+             break;
+         case 94:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_title_align(&current_match, result, get_string("alignment"));
+#else
+           fprintf(stderr, "cfg_title_align(%s)\n", get_string("alignment"));
+#endif
+             break;
+         case 95:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_output(&current_match, result, get_string("output"));
@@ -753,16 +769,16 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_output(%s)\n", get_string("output"));
 #endif
              break;
-         case 94:
+         case 96:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
-             cfg_criteria_init(&current_match, result, 30);
+             cfg_criteria_init(&current_match, result, 32);
 #else
-           fprintf(stderr, "cfg_criteria_init(%d)\n", 30);
-       cfg_criteria_init(&current_match, result, 30);
+           fprintf(stderr, "cfg_criteria_init(%d)\n", 32);
+       cfg_criteria_init(&current_match, result, 32);
 #endif
              break;
-         case 95:
+         case 97:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_ipc_socket(&current_match, result, get_string("path"));
@@ -770,7 +786,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_ipc_socket(%s)\n", get_string("path"));
 #endif
              break;
-         case 96:
+         case 98:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_show_marks(&current_match, result, get_string("value"));
@@ -778,7 +794,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_show_marks(%s)\n", get_string("value"));
 #endif
              break;
-         case 97:
+         case 99:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_start(&current_match, result);
@@ -786,28 +802,12 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_start()\n");
 #endif
              break;
-         case 98:
+         case 100:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_font(&current_match, result, get_string("font"));
 #else
            fprintf(stderr, "cfg_bar_font(%s)\n", get_string("font"));
-#endif
-             break;
-         case 99:
-             result->next_state = BAR;
-#ifndef TEST_PARSER
-             cfg_bar_mode(&current_match, result, get_string("mode"));
-#else
-           fprintf(stderr, "cfg_bar_mode(%s)\n", get_string("mode"));
-#endif
-             break;
-         case 100:
-             result->next_state = BAR;
-#ifndef TEST_PARSER
-             cfg_bar_mode(&current_match, result, get_string("mode"));
-#else
-           fprintf(stderr, "cfg_bar_mode(%s)\n", get_string("mode"));
 #endif
              break;
          case 101:
@@ -819,15 +819,22 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
 #endif
              break;
          case 102:
-             result->next_state = CRITERIA;
+             result->next_state = BAR;
 #ifndef TEST_PARSER
-             cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
+             cfg_bar_mode(&current_match, result, get_string("mode"));
 #else
-           fprintf(stderr, "cfg_criteria_add(%s, NULL)\n", get_string("ctype"));
-       cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
+           fprintf(stderr, "cfg_bar_mode(%s)\n", get_string("mode"));
 #endif
              break;
          case 103:
+             result->next_state = BAR;
+#ifndef TEST_PARSER
+             cfg_bar_mode(&current_match, result, get_string("mode"));
+#else
+           fprintf(stderr, "cfg_bar_mode(%s)\n", get_string("mode"));
+#endif
+             break;
+         case 104:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
              cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
@@ -836,7 +843,16 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
        cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
 #endif
              break;
-         case 104:
+         case 105:
+             result->next_state = CRITERIA;
+#ifndef TEST_PARSER
+             cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
+#else
+           fprintf(stderr, "cfg_criteria_add(%s, NULL)\n", get_string("ctype"));
+       cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
+#endif
+             break;
+         case 106:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_criteria_pop_state(&current_match, result);
@@ -845,33 +861,33 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
        cfg_criteria_pop_state(&current_match, result);
 #endif
              break;
-         case 105:
+         case 107:
              result->next_state = MODEBRACE;
 #ifndef TEST_PARSER
              cfg_enter_mode(&current_match, result, get_string("pango_markup"), get_string("modename"));
 #else
            fprintf(stderr, "cfg_enter_mode(%s, %s)\n", get_string("pango_markup"), get_string("modename"));
-#endif
-             break;
-         case 106:
-             result->next_state = CRITERIA;
-#ifndef TEST_PARSER
-             cfg_criteria_init(&current_match, result, 66);
-#else
-           fprintf(stderr, "cfg_criteria_init(%d)\n", 66);
-       cfg_criteria_init(&current_match, result, 66);
-#endif
-             break;
-         case 107:
-             result->next_state = CRITERIA;
-#ifndef TEST_PARSER
-             cfg_criteria_init(&current_match, result, 35);
-#else
-           fprintf(stderr, "cfg_criteria_init(%d)\n", 35);
-       cfg_criteria_init(&current_match, result, 35);
 #endif
              break;
          case 108:
+             result->next_state = CRITERIA;
+#ifndef TEST_PARSER
+             cfg_criteria_init(&current_match, result, 68);
+#else
+           fprintf(stderr, "cfg_criteria_init(%d)\n", 68);
+       cfg_criteria_init(&current_match, result, 68);
+#endif
+             break;
+         case 109:
+             result->next_state = CRITERIA;
+#ifndef TEST_PARSER
+             cfg_criteria_init(&current_match, result, 37);
+#else
+           fprintf(stderr, "cfg_criteria_init(%d)\n", 37);
+       cfg_criteria_init(&current_match, result, 37);
+#endif
+             break;
+         case 110:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_id(&current_match, result, get_string("bar_id"));
@@ -879,7 +895,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_id(%s)\n", get_string("bar_id"));
 #endif
              break;
-         case 109:
+         case 111:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_exec(&current_match, result, get_string("exectype"), get_string("no_startup_id"), get_string("command"));
@@ -887,7 +903,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_exec(%s, %s, %s)\n", get_string("exectype"), get_string("no_startup_id"), get_string("command"));
 #endif
              break;
-         case 110:
+         case 112:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_font(&current_match, result, get_string("font"));
@@ -895,7 +911,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_font(%s)\n", get_string("font"));
 #endif
              break;
-         case 111:
+         case 113:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_bar_finish(&current_match, result);
